@@ -8,18 +8,17 @@
   +--------------------------------------------------------------------+
   | Copyright (c) 2006, Thilo Raufeisen <traufeisen@php.net>           |
   | Copyright (c) 2013, Jim Jagielski <jimjag@php.net>                 |
+  | Copyright (c) 2016, Jakub Zelenka <bukka@php.net>                  |
   +--------------------------------------------------------------------+
 */
 
-/* $Id: php_gnupg.h 335919 2015-02-11 18:10:16Z jimjag $ */
-
 #ifndef PHP_GNUPG_H
 #define PHP_GNUPG_H
 
 extern zend_module_entry gnupg_module_entry;
 #define phpext_gnupg_ptr &gnupg_module_entry
 
-#define PHP_GNUPG_VERSION "1.3.6"
+#define PHP_GNUPG_VERSION "1.4.0"
 
 #ifdef PHP_WIN32
 #define PHP_GNUPG_API __declspec(dllexport)
@@ -32,21 +31,19 @@ extern zend_module_entry gnupg_module_entry;
 #endif
 
 #include <gpgme.h>
+#include "phpc/phpc.h"
 
-typedef struct gnupg_object{
-	zend_object zo;
+PHPC_OBJ_STRUCT_BEGIN(gnupg)
 	gpgme_ctx_t ctx;
-    gpgme_error_t err;
-    int errormode;
-    char* errortxt;
-    int signmode;
-    gpgme_key_t *encryptkeys;
-    unsigned int encrypt_size;
-    HashTable *signkeys;
-    HashTable *decryptkeys;
-} gnupg_object;
-
-static zend_class_entry *gnupg_class_entry;
+	gpgme_error_t err;
+	int errormode;
+	char* errortxt;
+	int signmode;
+	gpgme_key_t *encryptkeys;
+	unsigned int encrypt_size;
+	HashTable *signkeys;
+	HashTable *decryptkeys;
+PHPC_OBJ_STRUCT_END()
 
 PHP_MINIT_FUNCTION(gnupg);
 PHP_MSHUTDOWN_FUNCTION(gnupg);
